from django import template
from django.core.urlresolvers import reverse

register = template.Library()


@register.simple_tag
def get_admin_change_url(model_instance):
    info = (model_instance._meta.app_label, model_instance._meta.model_name)
    admin_url = reverse('admin:%s_%s_change' % info, args=(model_instance.pk,))
    return admin_url


# coding=utf-8
from __future__ import unicode_literals
from admin_monitoring.admin import admin_monitoring_mixin_factory


class VNP(object):
    """ для отображения числа новых компаний в админке """
    def __init__(self, model, vnp, **kwargs):
        self.model = model
        self.vnp_old = vnp
        self.kwargs = kwargs

    def __unicode__(self):
        # fixes UnicodeDecodeError
        return "%s" % self.__repr__()

    def __repr__(self):
        count = self.model.objects.filter(**self.kwargs).count()
        if count:
            return "%s (%s)" % (self.vnp_old, count)
        else:
            return self.vnp_old


def register(admin_site, model, model_admin=None, new_object_kwargs=None, seen_object_kwargs=None, **options):
    """
        пример использования: register(admin.site, Model, ModelAdmin, {"viewed": False})
        таким образом возле названия модели будет подписано число объектов с аттрибутом viewed=False
    """
    if not new_object_kwargs:
        new_object_kwargs = {}

    if not seen_object_kwargs:
        if len(new_object_kwargs.keys()) == 1:
            seen_object_kwargs = {
                new_object_kwargs.keys()[0]: not new_object_kwargs.values()[0]
            }
        elif len(new_object_kwargs.keys()) > 1:
            raise Exception("seen_object_kwargs must be specified in complex cases")

    AdminMonitoringMixin = admin_monitoring_mixin_factory(new_object_kwargs, seen_object_kwargs)

    class ModelAdmin(AdminMonitoringMixin, model_admin):
        pass

    if not hasattr(model._meta, "_verbose_name_plural"):
        model._meta._verbose_name_plural = model._meta.verbose_name_plural
    model._meta.verbose_name_plural = VNP(model, model._meta._verbose_name_plural, **new_object_kwargs)

    # class ProxyModel(model):
    #     class Meta:
    #         proxy = True
    #         verbose_name = model._meta.verbose_name
    #         verbose_name_plural = "%s" % VNP(model, model._meta.verbose_name_plural, **filter_kwargs)

    admin_site.register(model, ModelAdmin, **options)



import os
from setuptools import setup, find_packages

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django_admin_monitoring',
    version='0.1.2',
    packages=find_packages(),
    include_package_data=True,
    license='MIT License',
    description='A simple Django app that provides ability to monitor such things as user feedback in admin',
    long_description=README,
    url='https://github.com/eternalfame/django_admin_monitoring',
    author='Vyacheslav Sukhenko',
    author_email='eternalfame@mail.ru',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)


from django import forms
from django.conf.urls import patterns, url
from django.contrib import admin
from django.http import HttpResponse
from django.core.urlresolvers import reverse_lazy
from django.template import Template, Context


def admin_monitoring_mixin_factory(new_object_kwargs, seen_object_kwargs):

    class AdminMonitoringMixin(admin.ModelAdmin):
        def change_view(self, request, object_id, form_url='', extra_context=None):
            "now the object is seen. we're applying our seen kwargs"
            self.model.objects.filter(pk=object_id).update(**seen_object_kwargs)
            return super(AdminMonitoringMixin, self).change_view(request, object_id, form_url=form_url, extra_context=extra_context)

        def get_css_name(self):
            return '%s_%s_info_css' % (self.model._meta.app_label, self.model._meta.model_name)

        def get_urls(self):
            urls = super(AdminMonitoringMixin, self).get_urls()
            additional_urls = patterns('',
                url(r'^info.css$', self.admin_site.admin_view(self.get_css_view), name=self.get_css_name())
            )
            return additional_urls + urls

        def get_css_view(self, request):
            new_items = self.model.objects.filter(**new_object_kwargs)
            template = Template("""
                {% load admin_monitoring_tags %}
                {% if items %}{% for item in items %}a[href="{% get_admin_change_url item %}"]{% if not forloop.last %},{% endif %} {% endfor %}{
                    font-weight: bold;
                    text-decoration: underline;
                    color: red;
                }{% endif %}
            """)

            return HttpResponse(template.render(Context({
                'items': new_items
            })), content_type="text/css")

        def _media(self):
            return forms.Media(css={
                'screen': (reverse_lazy('admin:%s' % self.get_css_name()), )
            })
        media = property(_media)

    return AdminMonitoringMixin
